# SOM Lib

[![github workflow tests img]][github workflow tests]
[![github workflow release img]][github workflow release]
[![codecov img]][codecov]

[![code style img]][code style]
[![pre-commit img]][pre-commit]

[![github issues img]][github issues]
[![github tutorial img]][github tutorial]

[github workflow tests img]: https://github.com/melchugin/test-ci-cd-python/workflows/Tests/badge.svg?branch=master
[github workflow tests]: https://github.com/melchugin/test-ci-cd-python/actions?query=workflow%3ATests

[github workflow release img]: https://github.com/melchugin/test-ci-cd-python/workflows/Release/badge.svg
[github workflow release]: https://github.com/melchugin/test-ci-cd-python/actions?query=workflow%3ARelease

[codecov img]: https://codecov.io/gh/melchugin/test-ci-cd-python/branch/master/graph/badge.svg?token=WT3UQSNKPT
[codecov]: https://codecov.io/gh/melchugin/test-ci-cd-python

[code style img]: https://img.shields.io/badge/code%20style-black-000000.svg
[code style]: https://github.com/psf/black

[pre-commit img]: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
[pre-commit]: https://github.com/pre-commit/pre-commit

[github issues img]: https://img.shields.io/badge/issue_tracking-github-blue.svg
[github issues]: https://github.com/melchugin/test-ci-cd-python/issues

[github tutorial img]: https://img.shields.io/badge/PR-Welcome-%23FF8300.svg?
[github tutorial]: https://git-scm.com/book/en/v2/GitHub-Contributing-to-a-Project

## Description

Library for research and teaching of neural networks using second-order methods

XXX
